@@ -60,8 +60,6 @@ sppbi <- function(formula, id, data, est = "mom", nboot = 500){
       x[[kv2]]<-xmat[,k]
     }}
   xx<-x
-  #if(SEED)set.seed(2) # set seed of random number generator so that
-  #             results can be duplicated.
   # Next determine the n_j values
   nvec<-NA
   jp<-1-K
@@ -146,7 +144,23 @@ sppbi <- function(formula, id, data, est = "mom", nboot = 500){
   }
   bplus<-nboot+1
   sig.level<-1-sum(dv[bplus]>=dv[1:nboot])/nboot
-  result <- list(test = tvec, p.value = sig.level, call = cl)
+  
+  ## reorganizing output
+  if (length(tvec) > 1) {
+    tvec1 <- data.frame(Estimate = tvec)
+    rancomb <- apply(combn(levels(mf[,ranvar]), 2), 2, paste0, collapse = "-")
+    fnames <- levels(mf[,fixvar])
+    tnames <- as.vector(t(outer(fnames, rancomb, paste)))
+    if (length(fnames) > 2) {
+      rownames(tvec1) <- tnames
+    } else {
+      if (length(rancomb) == nrow(tvec1)) rownames(tvec1) <- rancomb
+    }  
+  } else {
+    tvec1 <- tvec
+  }
+  
+  result <- list(test = tvec1, p.value = sig.level, call = cl)
   class(result) <- c("spp")
   result
 }
\ No newline at end of file
